This crate contains kube-rs compatible bindings for Kubernetes custom resources for the jaegertracing.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
jaegertracing.io/v1
Jaeger